methodChannel property
The method channel used to interact with the native platform. The channel name 'html_to_pdf' matches the one used in Kotlin/Swift.
Implementation
@visibleForTesting
final methodChannel = const MethodChannel('html_to_pdf');
The method channel used to interact with the native platform. The channel name 'html_to_pdf' matches the one used in Kotlin/Swift.
@visibleForTesting
final methodChannel = const MethodChannel('html_to_pdf');