MethodChannelNativeHtmlToPdf class
An implementation of NativeHtmlToPdfPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- NativeHtmlToPdfPlatform
- MethodChannelNativeHtmlToPdf
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
The channel name 'html_to_pdf' matches the one used in Kotlin/Swift.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
convertHtmlToPdf(
Map< String, dynamic> args) → Future<String?> -
Converts HTML to PDF by calling the native implementation.
Accepts
argscontaining the HTML string and other configurations.override -
getPlatformVersion(
) → Future< String?> -
Retrieves the current platform version from the native side.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited